# Package alias for model-index

This is an alias for the [model-index](https://pypi.org/project/model-index/) library. 

**Please install the `model-index` package instead of this one!**

This package `modelindex` that has `model-index` as a dependency to act as an alias if the name is mistyped without the dash. 



